@@ -301,21 +301,21 @@ get_ui = function()
 				      style="padding-left:4em;"))),
 				tabPanel('Items', value='enorm_items',
 				  fluidRow(
-				    column(6,
-				      tags$h3('Item fit'),
-				      tags$hr(),
-				      enumericInput("enorm_slider_nbins","number of ability groups",min=2,step=1,value=5,inline=TRUE,width='5em'),
-				      plotSlider('enorm_slider',height='600px',width='100%')),
-				    column(6,
+				    column(5,
 				      tags$h3('Parameters'),
 				      tags$hr(),
-				      hidden(multiToggleButton('coef_format', selected='norm',btn_width='3em',style='float:right;margin-top:-12px;',
+				      hidden(multiToggleButton('coef_format', selected='norm',btn_width='3em',style='margin-left:20em;margin-top:-12px;',
 				                        choices=list(norm = tags$span(class="fa fa-list"),
 				                                     denorm = tags$i(class="fa fa-columns")))),
     				   tags$p(
     				     dataTableOutput('enorm_coef'),
-    				     download_buttons('enorm_coef')),
-				      style="padding-left:4em;")))),
+    				     download_buttons('enorm_coef')),style="padding-left:2em;"),
+				    column(7,
+				      tags$h3('Item fit'),
+				      tags$hr(),
+				      enumericInput("enorm_slider_nbins","number of ability groups",min=2,step=1,value=5,inline=TRUE,width='5em'),
+				      plotSlider('enorm_slider',height='600px',width='95%'),style="padding-right:8em;")
+				    ))),
 			  width=9)),
 		  value = 'enorm_pane'
 		),
